@@ -1,7 +1,7 @@
 package Bencher::Scenario::RoleTinyCommonsTree::descendants;
 
-our $DATE = '2016-07-03'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use strict;
 use warnings;
@@ -52,7 +52,7 @@ Bencher::Scenario::RoleTinyCommonsTree::descendants - Benchmark descendants()
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::RoleTinyCommonsTree::descendants (from Perl distribution Bencher-Scenarios-RoleTinyCommonsTree), released on 2016-07-03.
+This document describes version 0.04 of Bencher::Scenario::RoleTinyCommonsTree::descendants (from Perl distribution Bencher-Scenarios-RoleTinyCommonsTree), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -66,11 +66,15 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Code::Includable::Tree::NodeMethods> 0.10
+L<Code::Includable::Tree::NodeMethods> 0.11
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -110,34 +114,33 @@ A tree of height 7, ~20k objects
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m RoleTinyCommonsTree::descendants >>):
 
  #table1#
- +---------+-----------+-----------+------------+---------+---------+
- | dataset | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +---------+-----------+-----------+------------+---------+---------+
- | h7-o20k |      15.3 |     65.4  |          1 | 4.6e-05 |      20 |
- | h6-o1k  |     500   |      2    |         30 | 2.2e-05 |      20 |
- | h4-o100 |    4600   |      0.22 |        300 | 4.3e-07 |      20 |
- | h3-o15  |   34000   |      0.03 |       2200 | 5.3e-08 |      20 |
- +---------+-----------+-----------+------------+---------+---------+
+ +---------+-----------+-----------+------------+----------+---------+
+ | dataset | rate (/s) | time (ms) | vs_slowest |  errors  | samples |
+ +---------+-----------+-----------+------------+----------+---------+
+ | h7-o20k |        14 |    70     |          1 |   0.0001 |      22 |
+ | h6-o1k  |       410 |     2.5   |         29 | 1.2e-05  |      20 |
+ | h4-o100 |      3890 |     0.257 |        274 | 2.1e-07  |      20 |
+ | h3-o15  |     27000 |     0.038 |       1900 | 1.5e-07  |      23 |
+ +---------+-----------+-----------+------------+----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m RoleTinyCommonsTree::descendants --module-startup >>):
 
  #table2#
- +-------------------------------------+-----------+------------------------+------------+---------+---------+
- | participant                         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +-------------------------------------+-----------+------------------------+------------+---------+---------+
- | Code::Includable::Tree::NodeMethods |      12   |                    4.1 |        1   | 6.7e-05 |      21 |
- | perl -e1 (baseline)                 |       7.9 |                    0   |        1.5 | 3.6e-05 |      20 |
- +-------------------------------------+-----------+------------------------+------------+---------+---------+
+ +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant                         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Code::Includable::Tree::NodeMethods | 0.83                         | 4.2                | 16             |        16 |                      5 |        1   | 6.4e-05 |      20 |
+ | perl -e1 (baseline)                 | 1.2                          | 4.6                | 18             |        11 |                      0 |        1.5 | 3.8e-05 |      20 |
+ +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -161,7 +164,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
